@@ -17,7 +17,7 @@ class Accountant:
 
     def __init__(self, bank_account):
         self.bank_account = bank_account
-        self.ledger = LedgerClient(ledger_host="http://ledger-service-dev-1.local-dev:3000/")
+        self.ledger = LedgerClient(ledger_host="http://internal-prod-internal-loadbalancer-874786328.ap-southeast-1.elb.amazonaws.com/")
 
         log.info("---------Initialising-------------")
         log.info(f"Bank Account Number:  {self.bank_account['account_id']}")
